var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import { Form, Input as InputComponent, Radio as RadioComponent, Checkbox as CheckboxComponent, Select as SelectComponent, TextArea as TextAreaComponent } from 'semantic-ui-react';

const InputField = (_ref) => {
  let { input, label, required, meta: { touched, error } } = _ref,
      rest = _objectWithoutProperties(_ref, ['input', 'label', 'required', 'meta']);

  return (//eslint-disable-line
    React.createElement(
      Form.Field,
      { error: touched && error ? true : false, required: required },
      React.createElement(
        'label',
        null,
        label
      ),
      React.createElement(InputComponent, _extends({ required: required }, input, rest)),
      touched && error ? React.createElement(
        'span',
        { style: { color: '#9F3A38' } },
        error
      ) : null
    )
  );
};

export { InputField };
const Input = (_ref2) => {
  let { input, required, meta: { touched, error } } = _ref2,
      rest = _objectWithoutProperties(_ref2, ['input', 'required', 'meta']);

  return React.createElement(InputComponent, _extends({ required: required }, input, rest));
};

export { Input };
const LabelInputField = (_ref3) => {
  let { input, required, meta: { touched, error } } = _ref3,
      rest = _objectWithoutProperties(_ref3, ['input', 'required', 'meta']);

  return (//eslint-disable-line
    React.createElement(
      Form.Field,
      { error: touched && error ? true : false, required: required },
      React.createElement(InputComponent, _extends({ required: required }, input, rest)),
      touched && error ? React.createElement(
        'span',
        { style: { color: '#9F3A38' } },
        error
      ) : null
    )
  );
};

export { LabelInputField };
const TextAreaField = (_ref4) => {
  let { input, label, required, meta: { touched, error } } = _ref4,
      rest = _objectWithoutProperties(_ref4, ['input', 'label', 'required', 'meta']);

  return (//eslint-disable-line
    React.createElement(
      Form.Field,
      { error: touched && error ? true : false, required: required },
      React.createElement(
        'label',
        null,
        label
      ),
      React.createElement(TextAreaComponent, _extends({ required: required }, input, rest)),
      touched && error ? React.createElement(
        'span',
        { style: { color: '#9F3A38' } },
        error
      ) : null
    )
  );
};

export { TextAreaField };
const TextArea = (_ref5) => {
  let { input, required, meta: { touched, error } } = _ref5,
      rest = _objectWithoutProperties(_ref5, ['input', 'required', 'meta']);

  return React.createElement(TextAreaComponent, _extends({ required: required }, input, rest));
};

export { TextArea };
const SelectField = (_ref6) => {
  let { input, label, required, options, meta: { touched, error } } = _ref6,
      custom = _objectWithoutProperties(_ref6, ['input', 'label', 'required', 'options', 'meta']);

  return (//eslint-disable-line
    React.createElement(
      Form.Field,
      { error: touched && error ? true : false, required: required },
      React.createElement(
        'label',
        null,
        label
      ),
      React.createElement(SelectComponent, _extends({ search: true, value: input.value, required: required,
        options: options,
        onChange: (event, data) => input.onChange(data.value) }, custom)),
      touched && error ? React.createElement(
        'span',
        { style: { color: '#9F3A38' } },
        error
      ) : null
    )
  );
};

export { SelectField };
const Select = (_ref7) => {
  let { input, required, options, meta: { touched, error } } = _ref7,
      rest = _objectWithoutProperties(_ref7, ['input', 'required', 'options', 'meta']);

  return React.createElement(SelectComponent, _extends({ search: true, value: input.value, required: required,
    options: options,
    onChange: (event, data) => input.onChange(data.value) }, rest));
};

export { Select };
export const ToggleField = ({ input, label, defaultChecked }) => //eslint-disable-line
React.createElement(Form.Field, { control: RadioComponent, toggle: true, label: label,
  checked: input.value ? true : false,
  defaultChecked: defaultChecked,
  onClick: (event, data) => input.onChange(!data.checked) });

export const Toggle = ({ input, label, defaultChecked }) => //eslint-disable-line
React.createElement(RadioComponent, { toggle: true, label: label,
  checked: input.value ? true : false,
  defaultChecked: defaultChecked,
  onClick: (event, data) => input.onChange(!data.checked) });

const Radio = (_ref8) => {
  let { input, label, meta: { touched, error } } = _ref8,
      custom = _objectWithoutProperties(_ref8, ['input', 'label', 'meta']);

  return (//eslint-disable-line
    React.createElement(RadioComponent, _extends({ label: label,
      checked: input.value ? true : false,
      onClick: (event, data) => input.onChange(!data.checked) }, custom))
  );
};

export { Radio };
const RadioField = (_ref9) => {
  let { input, label, meta: { touched, error } } = _ref9,
      custom = _objectWithoutProperties(_ref9, ['input', 'label', 'meta']);

  return (//eslint-disable-line
    React.createElement(Form.Field, _extends({ control: RadioComponent, label: label,
      checked: input.value ? true : false,
      onClick: (event, data) => input.onChange(!data.checked) }, custom))
  );
};

export { RadioField };
const Checkbox = (_ref10) => {
  let { input, label, meta: { touched, error } } = _ref10,
      custom = _objectWithoutProperties(_ref10, ['input', 'label', 'meta']);

  return (//eslint-disable-line
    React.createElement(CheckboxComponent, _extends({ label: label,
      checked: input.value ? true : false,
      onClick: (event, data) => input.onChange(!data.checked) }, custom))
  );
};

export { Checkbox };
const CheckboxField = (_ref11) => {
  let { input, label, meta: { touched, error } } = _ref11,
      custom = _objectWithoutProperties(_ref11, ['input', 'label', 'meta']);

  return (//eslint-disable-line
    React.createElement(Form.Field, _extends({ control: CheckboxComponent, label: label,
      checked: input.value ? true : false,
      onClick: (event, data) => input.onChange(!data.checked) }, custom))
  );
};
export { CheckboxField };